Module: Aws::SimpleDBv2
- Defined in:
- lib/aws-sdk-simpledbv2/endpoint_parameters.rb,
lib/aws-sdk-simpledbv2/plugins/endpoints.rb,
lib/aws-sdk-simpledbv2/endpoint_provider.rb,
lib/aws-sdk-simpledbv2/client_api.rb,
lib/aws-sdk-simpledbv2/endpoints.rb,
lib/aws-sdk-simpledbv2/resource.rb,
lib/aws-sdk-simpledbv2/waiters.rb,
lib/aws-sdk-simpledbv2/errors.rb,
lib/aws-sdk-simpledbv2/client.rb,
lib/aws-sdk-simpledbv2/types.rb,
lib/aws-sdk-simpledbv2.rb
Overview
This module provides support for Amazon SimpleDB v2. This module is available in the ‘aws-sdk-simpledbv2` gem.
# Client
The Client class provides one method for each API operation. Operation methods each accept a hash of request parameters and return a response structure.
simple_d_bv_2 = Aws::SimpleDBv2::Client.new
resp = simple_d_bv_2.get_export(params)
See Client for more information.
# Errors
Errors returned from Amazon SimpleDB v2 are defined in the Errors module and all extend Errors::ServiceError.
begin
# do stuff
rescue Aws::SimpleDBv2::Errors::ServiceError
# rescues all Amazon SimpleDB v2 API errors
end
See Errors for more information.
Defined Under Namespace
Modules: ClientApi, Endpoints, Errors, Plugins, Types, Waiters Classes: Client, EndpointParameters, EndpointProvider, Resource
service collapse
- GEM_VERSION =
'1.3.0'