Module: Aws::SimpleDBv2::Errors
- Extended by:
- Errors::DynamicErrors
- Defined in:
- lib/aws-sdk-simpledbv2/errors.rb
Overview
When SimpleDBv2 returns an error response, the Ruby SDK constructs and raises an error. These errors all extend Aws::SimpleDBv2::Errors::ServiceError < Errors::ServiceError
You can rescue all SimpleDBv2 errors using ServiceError:
begin
# do stuff
rescue Aws::SimpleDBv2::Errors::ServiceError
# rescues all SimpleDBv2 API errors
end
## Request Context ServiceError objects have a #context method that returns information about the request that generated the error. See Seahorse::Client::RequestContext for more information.
## Error Classes
Additionally, error classes are dynamically generated for service errors based on the error code if they are not defined above.
Defined Under Namespace
Classes: ConflictException, InvalidNextTokenException, InvalidParameterCombinationException, InvalidParameterValueException, NoSuchDomainException, NoSuchExportException, NumberExportsLimitExceeded