Class: Aws::SimpleDBv2::Types::ExportSummary

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-simpledbv2/types.rb

Overview

Summary information about an export, including its unique identifier, current status, creation time, and the domain being exported.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domain_nameString

The name of the domain for which the export was created.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-simpledbv2/types.rb', line 50

class ExportSummary < Struct.new(
  :export_arn,
  :export_status,
  :requested_at,
  :domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#export_arnString

Unique ARN identifier of the export.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-simpledbv2/types.rb', line 50

class ExportSummary < Struct.new(
  :export_arn,
  :export_status,
  :requested_at,
  :domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#export_statusString

The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.

Returns:

  • (String)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-simpledbv2/types.rb', line 50

class ExportSummary < Struct.new(
  :export_arn,
  :export_status,
  :requested_at,
  :domain_name)
  SENSITIVE = []
  include Aws::Structure
end

#requested_atTime

Timestamp when the export request was received by the service

Returns:

  • (Time)


50
51
52
53
54
55
56
57
# File 'lib/aws-sdk-simpledbv2/types.rb', line 50

class ExportSummary < Struct.new(
  :export_arn,
  :export_status,
  :requested_at,
  :domain_name)
  SENSITIVE = []
  include Aws::Structure
end