Class: Aws::SimpleDBv2::Types::GetExportResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-simpledbv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The client token provided for this export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#domain_nameString

The name of the domain that was exported.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_arnString

Unique ARN identifier of the export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_data_cutoff_timeTime

The timestamp indicating the cutoff point for data inclusion in the export. All data inserted or modified before this time will be present in the exported data. Data insertions or modifications after this timestamp may or may not be present in the export.

Returns:

  • (Time)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_manifestString

The name of the manifest summary file for the export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#export_statusString

The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

Failure code for the result of the failed export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

Export failure reason description.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#items_countInteger

Total number of exported items.

Returns:

  • (Integer)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#requested_atTime

Timestamp when the export request was received by the service.

Returns:

  • (Time)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketString

The name of the S3 bucket for this export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket_ownerString

The S3 bucket owner account ID for this export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_key_prefixString

The S3 key prefix provided in the corresponding StartDomainExport request.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_sse_algorithmString

The S3 SSE encryption algorithm for this export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end

#s3_sse_kms_key_idString

The KMS key ID for this export.

Returns:

  • (String)


140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140

class GetExportResponse < Struct.new(
  :export_arn,
  :client_token,
  :export_status,
  :domain_name,
  :requested_at,
  :s3_bucket,
  :s3_key_prefix,
  :s3_sse_algorithm,
  :s3_sse_kms_key_id,
  :s3_bucket_owner,
  :failure_code,
  :failure_message,
  :export_manifest,
  :items_count,
  :export_data_cutoff_time)
  SENSITIVE = []
  include Aws::Structure
end