Class: Aws::SimpleDBv2::Types::StartDomainExportResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-simpledbv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

The client token that was provided in the request.

Returns:

  • (String)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359

class StartDomainExportResponse < Struct.new(
  :client_token,
  :export_arn,
  :requested_at)
  SENSITIVE = []
  include Aws::Structure
end

#export_arnString

Unique ARN identifier of the export.

Returns:

  • (String)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359

class StartDomainExportResponse < Struct.new(
  :client_token,
  :export_arn,
  :requested_at)
  SENSITIVE = []
  include Aws::Structure
end

#requested_atTime

Timestamp when the export request was received by the service.

Returns:

  • (Time)


359
360
361
362
363
364
365
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359

class StartDomainExportResponse < Struct.new(
  :client_token,
  :export_arn,
  :requested_at)
  SENSITIVE = []
  include Aws::Structure
end