Class: Aws::SimpleDBv2::Types::GetExportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SimpleDBv2::Types::GetExportResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-simpledbv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token provided for this export.
-
#domain_name ⇒ String
The name of the domain that was exported.
-
#export_arn ⇒ String
Unique ARN identifier of the export.
-
#export_data_cutoff_time ⇒ Time
The timestamp indicating the cutoff point for data inclusion in the export.
-
#export_manifest ⇒ String
The name of the manifest summary file for the export.
-
#export_status ⇒ String
The current state of the export.
-
#failure_code ⇒ String
Failure code for the result of the failed export.
-
#failure_message ⇒ String
Export failure reason description.
-
#items_count ⇒ Integer
Total number of exported items.
-
#requested_at ⇒ Time
Timestamp when the export request was received by the service.
-
#s3_bucket ⇒ String
The name of the S3 bucket for this export.
-
#s3_bucket_owner ⇒ String
The S3 bucket owner account ID for this export.
-
#s3_key_prefix ⇒ String
The S3 key prefix provided in the corresponding StartDomainExport request.
-
#s3_sse_algorithm ⇒ String
The S3 SSE encryption algorithm for this export.
-
#s3_sse_kms_key_id ⇒ String
The KMS key ID for this export.
Instance Attribute Details
#client_token ⇒ String
The client token provided for this export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain that was exported.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#export_arn ⇒ String
Unique ARN identifier of the export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#export_data_cutoff_time ⇒ Time
The timestamp indicating the cutoff point for data inclusion in the export. All data inserted or modified before this time will be present in the exported data. Data insertions or modifications after this timestamp may or may not be present in the export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#export_manifest ⇒ String
The name of the manifest summary file for the export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#export_status ⇒ String
The current state of the export. Current possible values include : PENDING - export request received, IN_PROGRESS - export is being processed, SUCCEEDED - export completed successfully, and FAILED - export encountered an error.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
Failure code for the result of the failed export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Export failure reason description.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#items_count ⇒ Integer
Total number of exported items.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#requested_at ⇒ Time
Timestamp when the export request was received by the service.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The name of the S3 bucket for this export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner ⇒ String
The S3 bucket owner account ID for this export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#s3_key_prefix ⇒ String
The S3 key prefix provided in the corresponding StartDomainExport request.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#s3_sse_algorithm ⇒ String
The S3 SSE encryption algorithm for this export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |
#s3_sse_kms_key_id ⇒ String
The KMS key ID for this export.
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 140 class GetExportResponse < Struct.new( :export_arn, :client_token, :export_status, :domain_name, :requested_at, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner, :failure_code, :failure_message, :export_manifest, :items_count, :export_data_cutoff_time) SENSITIVE = [] include Aws::Structure end |