Class: Aws::SimpleDBv2::Types::StartDomainExportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SimpleDBv2::Types::StartDomainExportRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-simpledbv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Providing a ClientToken makes the call to StartDomainExport API idempotent, meaning that multiple identical calls have the same effect as one single call.
-
#domain_name ⇒ String
The name of the domain to export.
-
#s3_bucket ⇒ String
The name of the S3 bucket where the domain data will be exported.
-
#s3_bucket_owner ⇒ String
The ID of the AWS account that owns the bucket the export will be stored in.
-
#s3_key_prefix ⇒ String
The prefix string to be used to generate the S3 object keys for export artifacts.
-
#s3_sse_algorithm ⇒ String
The server-side encryption algorithm to use for the exported data in S3.
-
#s3_sse_kms_key_id ⇒ String
The KMS key ID to use for server-side encryption with AWS KMS-managed keys (SSE-KMS).
Instance Attribute Details
#client_token ⇒ String
Providing a ClientToken makes the call to StartDomainExport API idempotent, meaning that multiple identical calls have the same effect as one single call. A client token is valid for 8 hours after the first request that uses it is completed. After 8 hours, any request with the same client token is treated as a new request. Do not resubmit the same request with the same client token for more than 8 hours, or the result might not be idempotent. If you submit a request with the same client token but a change in other parameters within the 8-hour idempotency window, a ConflictException will be returned.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain to export.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The name of the S3 bucket where the domain data will be exported.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_owner ⇒ String
The ID of the AWS account that owns the bucket the export will be stored in.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#s3_key_prefix ⇒ String
The prefix string to be used to generate the S3 object keys for export artifacts.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#s3_sse_algorithm ⇒ String
The server-side encryption algorithm to use for the exported data in S3. Valid values are: AES256 (SSE-S3) and KMS (SSE-KMS). If not specified, bucket’s default encryption will apply.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |
#s3_sse_kms_key_id ⇒ String
The KMS key ID to use for server-side encryption with AWS KMS-managed keys (SSE-KMS). This parameter is only expected with KMS as the S3 SSE algorithm.
333 334 335 336 337 338 339 340 341 342 343 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 333 class StartDomainExportRequest < Struct.new( :client_token, :domain_name, :s3_bucket, :s3_key_prefix, :s3_sse_algorithm, :s3_sse_kms_key_id, :s3_bucket_owner) SENSITIVE = [] include Aws::Structure end |