Class: Aws::SimpleDBv2::Types::StartDomainExportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SimpleDBv2::Types::StartDomainExportResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-simpledbv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that was provided in the request.
-
#export_arn ⇒ String
Unique ARN identifier of the export.
-
#requested_at ⇒ Time
Timestamp when the export request was received by the service.
Instance Attribute Details
#client_token ⇒ String
The client token that was provided in the request.
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359 class StartDomainExportResponse < Struct.new( :client_token, :export_arn, :requested_at) SENSITIVE = [] include Aws::Structure end |
#export_arn ⇒ String
Unique ARN identifier of the export.
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359 class StartDomainExportResponse < Struct.new( :client_token, :export_arn, :requested_at) SENSITIVE = [] include Aws::Structure end |
#requested_at ⇒ Time
Timestamp when the export request was received by the service.
359 360 361 362 363 364 365 |
# File 'lib/aws-sdk-simpledbv2/types.rb', line 359 class StartDomainExportResponse < Struct.new( :client_token, :export_arn, :requested_at) SENSITIVE = [] include Aws::Structure end |